/*
**    DRIDEFLT.SQL
**
**    Add a DEFAULT constraint.
*/


PRINT 'Begin DRIDEFLT.SQL'
GO

USE Credit
SET NOCOUNT ON
GO
IF ( (SELECT db_name()) <> 'Credit')
BEGIN
   RAISERROR ('Database "Credit" not found.',22,127) WITH LOG
END
GO


/*
**    Optional numeric fields default to zero.
*/


IF EXISTS (SELECT name FROM sysobjects WHERE name = 'member_prev_balance_default')
  ALTER TABLE member
    DROP CONSTRAINT member_prev_balance_default
GO
ALTER TABLE member
  ADD CONSTRAINT member_prev_balance_default DEFAULT 0 FOR prev_balance
GO

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'member_curr_balance_default')
  ALTER TABLE member
    DROP CONSTRAINT member_curr_balance_default
GO
ALTER TABLE member
  ADD CONSTRAINT member_curr_balance_default DEFAULT 0 FOR curr_balance
GO

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'charge_statement_no_default')
  ALTER TABLE charge
    DROP CONSTRAINT charge_statement_no_default
GO
ALTER TABLE charge
  ADD CONSTRAINT charge_statement_no_default DEFAULT 0 FOR statement_no
GO

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'payment_statement_no_default')
  ALTER TABLE payment
    DROP CONSTRAINT payment_statement_no_default
GO
ALTER TABLE payment
  ADD CONSTRAINT payment_statement_no_default DEFAULT 0 FOR statement_no
GO



/*
**    Members and providers are good for one year.
*/


IF EXISTS (SELECT name FROM sysobjects WHERE name = 'provider_issue_dt_default')
  ALTER TABLE provider
    DROP CONSTRAINT provider_issue_dt_default
GO
ALTER TABLE provider
  ADD CONSTRAINT provider_issue_dt_default DEFAULT getdate() FOR issue_dt
GO

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'provider_expr_dt_default')
  ALTER TABLE provider
    DROP CONSTRAINT provider_expr_dt_default
GO
ALTER TABLE provider
  ADD CONSTRAINT provider_expr_dt_default DEFAULT dateadd(year,1,getdate()) FOR expr_dt
GO

  
IF EXISTS (SELECT name FROM sysobjects WHERE name = 'member_issue_dt_default')
  ALTER TABLE member
    DROP CONSTRAINT member_issue_dt_default
GO
ALTER TABLE member
  ADD CONSTRAINT member_issue_dt_default DEFAULT getdate() FOR issue_dt
GO

IF EXISTS (SELECT name FROM sysobjects WHERE name = 'member_expr_dt_default')
  ALTER TABLE member
    DROP CONSTRAINT member_expr_dt_default
GO
ALTER TABLE member
  ADD CONSTRAINT member_expr_dt_default DEFAULT dateadd(year,1,getdate()) FOR expr_dt
GO

  
/*
**    All status codes start as '  ' (ACTIVE).
*/


IF EXISTS (SELECT name FROM sysobjects WHERE name = 'region_status_default')
  ALTER TABLE region
    DROP CONSTRAINT region_status_default
GO
ALTER TABLE region
  ADD CONSTRAINT region_status_default DEFAULT '  ' FOR region_code
GO

  
IF EXISTS (SELECT name FROM sysobjects WHERE name = 'category_status_default')
  ALTER TABLE category
    DROP CONSTRAINT category_status_default
GO
ALTER TABLE category
  ADD CONSTRAINT category_status_default DEFAULT '  ' FOR category_code
GO

  
IF EXISTS (SELECT name FROM sysobjects WHERE name = 'provider_status_default')
  ALTER TABLE provider
    DROP CONSTRAINT provider_status_default
GO
ALTER TABLE provider
  ADD CONSTRAINT provider_status_default DEFAULT '  ' FOR provider_code
GO

  
IF EXISTS (SELECT name FROM sysobjects WHERE name = 'corporation_status_default')
  ALTER TABLE corporation
    DROP CONSTRAINT corporation_status_default
GO
ALTER TABLE corporation
  ADD CONSTRAINT corporation_status_default DEFAULT '  ' FOR corp_code
GO

  
IF EXISTS (SELECT name FROM sysobjects WHERE name = 'member_status_default')
  ALTER TABLE member
    DROP CONSTRAINT member_status_default
GO
ALTER TABLE member
  ADD CONSTRAINT member_status_default DEFAULT '  ' FOR member_code
GO

  
IF EXISTS (SELECT name FROM sysobjects WHERE name = 'statement_status_default')
  ALTER TABLE statement
    DROP CONSTRAINT statement_status_default
GO
ALTER TABLE statement
  ADD CONSTRAINT statement_status_default DEFAULT '  ' FOR statement_code
GO

  
IF EXISTS (SELECT name FROM sysobjects WHERE name = 'payment_status_default')
  ALTER TABLE payment
    DROP CONSTRAINT payment_status_default
GO
ALTER TABLE payment
  ADD CONSTRAINT payment_status_default DEFAULT '  ' FOR payment_code
GO

  
IF EXISTS (SELECT name FROM sysobjects WHERE name = 'charge_status_default')
  ALTER TABLE charge
    DROP CONSTRAINT charge_status_default
GO
ALTER TABLE charge
  ADD CONSTRAINT charge_status_default DEFAULT '  ' FOR charge_code
GO

